@@ -37,7 +37,7 @@ import org.wildfly.common.cpu.ProcessorInfo;
  */
 public class SpinLock implements ExtendedLock {
     private static final long ownerOffset;
-    private static final int spinLimit;
+    private static final int defaultSpinLimit;
 
     static {
         try {
@@ -45,7 +45,7 @@ public class SpinLock implements ExtendedLock {
         } catch (NoSuchFieldException e) {
             throw new NoSuchFieldError(e.getMessage());
         }
-        spinLimit = AccessController.doPrivileged(
+        defaultSpinLimit = AccessController.doPrivileged(
             (PrivilegedAction<Integer>) () -> Integer.valueOf(
                 System.getProperty("jboss.spin-lock.limit", ProcessorInfo.availableProcessors() == 1 ? "0" : "5000")
             )
@@ -57,10 +57,24 @@ public class SpinLock implements ExtendedLock {
 
     private int level;
 
+    private final int spinLimit;
+
     /**
      * Construct a new instance.
      */
-    public SpinLock() {}
+    public SpinLock() {
+        this(defaultSpinLimit);
+    }
+
+    /**
+     * Construct a new instance with the given spin limit.
+     *
+     * @param spinLimit the spin limit to use for this instance
+     */
+    public SpinLock(final int spinLimit) {
+        Assert.checkMinimumParameter("spinLimit", 0, spinLimit);
+        this.spinLimit = spinLimit;
+    }
 
     /**
      * Determine if this spin lock is held.  Useful for assertions.
